@@ -1,5 +1,6 @@
 from .backends.autodetect import choose_backend
 from .backends.base import Device
+from .errors import NoBackendError
 from .task import HotplugDetector
 
-__all__ = ("choose_backend", "Device", "HotplugDetector")
+__all__ = ("choose_backend", "Device", "HotplugDetector", "NoBackendError")
